@@ -26,6 +26,10 @@ format_gof <- function(gof, fmt, gof_map, ...) {
   gm_clean <- as.character(sapply(gof_map, function(x) x$clean))
 
   # formating arguments priority: `fmt` > `gof_map` > 3
+  if (inherits(fmt, "fmt_statistic")) {
+    gof <- fmt(gof, unknown = FALSE)
+  }
+
   for (g in gof_map) {
     if (is.numeric(gof[[g$raw]])) {
       if (g$raw %in% colnames(gof)) {
