@@ -1,5 +1,5 @@
-# Adapted from `vtable` by Nick Huntington-Klein under MIT license
-weighted.sd <- function(x, w) {
+weighted_sd <- function(x, w) {
+  # Adapted from `vtable` by Nick Huntington-Klein under MIT license
   if (min(w) < 0) {
     stop('Negative weights found.')
   }
@@ -15,4 +15,4 @@ weighted.sd <- function(x, w) {
   var_x <- sum(w * ((x - mean_x)^2)) / (weightsum * (num_nonzero - 1) / num_nonzero)
   sd_x <- sqrt(var_x)
   return(sd_x)
-}
+}
\ No newline at end of file
